from setuptools import setup

setup(name='deep_nest',
      version='0.12',
      description='A sane approach to arbitrarily nested dictionaries (*cough* nested JSON *cough*)',
      url='https://github.com/lruhlen/deep_nest',
      author='L. Ruhlen',
      author_email='ruhlen@gmail.com',
      license='MIT',
      packages=['deep_nest'],
      install_requires=[],
      zip_safe=False)
